================
PETSc for Python
================

Overview
--------

Welcome to PETSc for Python. This package provides Python bindings for
PETSc_, the *Portable, Extensible Toolkit for Scientific Computation*.

Dependencies
------------

* Python_ 2.7, 3.3 or above.

* A recent NumPy_ release.

* A matching version of PETSc_ built with *shared/dynamic libraries*.

* To work with the in-development version, you need Cython_.

.. _Python: https://www.python.org
.. _NumPy:  https://www.numpy.org
.. _PETSc:  https://petsc.org
.. _Cython: https://www.cython.org

Documentation
-------------

* https://petsc.org/release/petsc4py/petsc4py/
